==> wicket-jquery-ui-core-6.19.2-sources.jar: com/googlecode/wicket/jquery/core/ajax/IJQueryAjaxAware.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.googlecode.wicket.jquery.core.ajax;

import org.apache.wicket.ajax.AjaxRequestTarget;

import com.googlecode.wicket.jquery.core.JQueryBehavior;
import com.googlecode.wicket.jquery.core.JQueryEvent;

/**
 * Specifies that the implementing class, usually a {@link JQueryBehavior}, is aware of ajax calls that may be made by a {@link JQueryAjaxBehavior}<br/>
 * 
 * @author Sebastien Briquet - sebfz1
 * @see JQueryAjaxBehavior
 */
public interface IJQueryAjaxAware
{
	/**
	 * Event triggered when a {@link JQueryAjaxBehavior} receives an ajax notification from the widget
	 * 
	 * @param target the {@link AjaxRequestTarget}
	 * @param event the {@link JQueryEvent}
	 */
	void onAjax(AjaxRequestTarget target, JQueryEvent event);
}

==> wicket-jquery-ui-core-7.6.0-sources.jar: com/googlecode/wicket/jquery/core/ajax/IJQueryAjaxAware.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.googlecode.wicket.jquery.core.ajax;

import org.apache.wicket.ajax.AjaxRequestTarget;

import com.googlecode.wicket.jquery.core.JQueryBehavior;
import com.googlecode.wicket.jquery.core.JQueryEvent;

/**
 * Specifies that the implementing class, usually a {@link JQueryBehavior}, is aware of ajax calls that may be made by a {@link JQueryAjaxBehavior}<br>
 * 
 * @author Sebastien Briquet - sebfz1
 * @see JQueryAjaxBehavior
 */
public interface IJQueryAjaxAware
{
	/**
	 * Event triggered when a {@link JQueryAjaxBehavior} receives an ajax notification from the widget
	 * 
	 * @param target the {@link AjaxRequestTarget}
	 * @param event the {@link JQueryEvent}
	 */
	void onAjax(AjaxRequestTarget target, JQueryEvent event);
}
